<?php
/**
 * Customizer Multicheck Control.
 * 
 * @package Ogma
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Ogma_Control_Multicheck' ) ) :

	/**
	 * Multi check control
	 */
	class Ogma_Control_Multicheck extends WP_Customize_Control {

		/**
		 * The control type.
		 *
		 * @access public
		 * @var string
		 * @since  1.0.0
		 */
		public $type = 'ogma-multi-check';

		/**
         * The control version.
         *
         * @static
         * @access public
         * @since 1.0
         * @var string
         */
        public static $control_version = '1.0.0';

		/**
         * Enqueue control related scripts/styles.
         *
         * @access public
         * @return void
         * @since  1.0.0
         */
		public function enqueue() {
			
			wp_enqueue_style( 'ogma-multicheck', get_template_directory_uri() . '/inc/customizer/custom-controls/multicheck/multicheck.css', null, self::$control_version );

			wp_enqueue_script( 'ogma-multicheck', get_template_directory_uri() . '/inc/customizer/custom-controls/multicheck/multicheck.js', array( 'jquery', 'customize-base' ), self::$control_version, true );

		}

		/**
         * Refresh the parameters passed to the JavaScript via JSON.
         *
         * @see WP_Customize_Control::to_json()
         * @since 1.0.0
         */
		public function to_json() {
			parent::to_json();

			if ( isset( $this->default ) ) {
				$this->json['default'] = $this->default;
			} else {
				$this->json['default'] = $this->setting->default;
			}
			$this->json['value']       = $this->value();
			$this->json['choices']     = $this->choices;
			$this->json['link']        = $this->get_link();
			$this->json['id']          = $this->id;

			$this->json['inputAttrs'] = '';
			foreach ( $this->input_attrs as $attr => $value ) {
				$this->json['inputAttrs'] .= $attr . '="' . esc_attr( $value ) . '" ';
			}

		}

		/**
		 * An Underscore (JS) template for this control's content (but not its container).
		 *
		 * Class variables for this control class are available in the `data` JS object;
		 * export custom variables by overriding {@see WP_Customize_Control::to_json()}.
		 *
		 * @see WP_Customize_Control::print_template()
		 *
		 * @access protected
		 * @since 1.0.0
		 */
		protected function content_template() {
			?>
			<# if ( ! data.choices ) { return; } #>

			<# if ( data.label ) { #>
				<span class="customize-control-title">{{ data.label }}</span>
			<# } #>

			<# if ( data.description ) { #>
				<span class="description customize-control-description">{{{ data.description }}}</span>
			<# } #>

			<ul>
				<# for ( key in data.choices ) { #>
					<li>
						<label>
							<input {{{ data.inputAttrs }}} type="checkbox" value="{{ key }}"<# if ( _.contains( data.value, key ) ) { #> checked<# } #> />
							{{ data.choices[ key ] }}
						</label>
					</li>
				<# } #>
			</ul>
			<?php
		}
	}

endif;
