<?php
/**
 * Add Preloader section and it's fields inside General Settings panel.
 * 
 * @package Ogma
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

add_action( 'customize_register', 'ogma_register_preloader_options' );

if ( ! function_exists( 'ogma_register_preloader_options' ) ) :

    /**
     * Register theme options for Preloader section.
     * 
     * @param WP_Customize_Manager $wp_customize Object that holds the customizer data.
     * @since 1.0.0
     */
    function ogma_register_preloader_options( $wp_customize ) {

        /*
         * Failsafe is safe
         */
        if ( ! isset( $wp_customize ) ) {
            return;
        }

        /**
         * Add Site Style Section
         * 
         * General Settings > Preloader
         * 
         * @uses $wp_customize->add_section() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_section/
         * @since 1.0.0
         */
        $wp_customize->add_section( new Ogma_Customize_Section (
            $wp_customize, 'ogma_section_preloader',
                array(
                    'priority'              => 20,
                    'panel'                 => 'ogma_panel_general',
                    'title'                 => __( 'Preloader', 'ogma' ),
                )
            )
        );

        /**
         * Toggle option for preloader.
         *
         * General Settings > Preloader
         *
         * @since 1.0.0
         */
        $wp_customize->add_setting( 'preloader_enable',
            array(
                'default'           => ogma_get_customizer_default ( 'preloader_enable' ),
                'sanitize_callback' => 'ogma_sanitize_checkbox'
            )
        );
        $wp_customize->add_control( new Ogma_Control_Toggle(
            $wp_customize, 'preloader_enable',
                array(
                    'priority'      => 10,
                    'section'       => 'ogma_section_preloader',
                    'settings'      => 'preloader_enable',
                    'label'         => __( 'Enable Preloader', 'ogma' )
                )
            )
        );

        /**
         * Radio image field for preloader styles
         *
         * General Settings > Preloader
         *
         * @since 1.0.0
         */
        $wp_customize->add_setting( 'preloader_style',
            array(
                'default'           => ogma_get_customizer_default ( 'preloader_style' ),
                'sanitize_callback' => 'ogma_sanitize_select',
            )
        );
        $wp_customize->add_control( new Ogma_Control_Radio_Image(
            $wp_customize, 'preloader_style',
                array(
                    'priority'          => 20,
                    'section'           => 'ogma_section_preloader',
                    'settings'          => 'preloader_style',
                    'label'             => __( 'Preloader Layout', 'ogma' ),
                    'choices'           => ogma_preloader_style_choices(),
                    'input_attrs'       => array(
                        'column'    => 4,
                    ),
                    'active_callback'   => 'ogma_cb_has_enable_preloader'
                )
            )
        );

        /**
         * Upgrade field for preloader section
         * 
         * General Settings > Preloader
         *
         * @since 1.0.0
         */ 
        $wp_customize->add_setting( 'upgrade_preloader',
            array(
                'sanitize_callback' => 'sanitize_text_field'
            )
        );
        $wp_customize->add_control( new Ogma_Control_Upgrade(
            $wp_customize, 'upgrade_preloader',
                array(
                    'priority'      => 70,
                    'section'       => 'ogma_section_preloader',
                    'settings'      => 'upgrade_preloader',
                    'label'         => __( 'More features with Ogma Pro', 'ogma' ),
                    'choices'       => ogma_upgrade_choices( 'ogma_preloader' )
                )
            )
        );

    }

endif;