<?php
/**
 * Add Scroll Top section and it's fields inside General Settings panel.
 * 
 * @package Ogma
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

add_action( 'customize_register', 'ogma_register_scroll_top_options' );

if ( ! function_exists( 'ogma_register_scroll_top_options' ) ) :

    /**
     * Register theme options for Scroll Top section.
     * 
     * @param WP_Customize_Manager $wp_customize Object that holds the customizer data.
     * @since 1.0.0
     */
    function ogma_register_scroll_top_options( $wp_customize ) {

        /*
         * Failsafe is safe
         */
        if ( ! isset( $wp_customize ) ) {
            return;
        }

        /**
         * Add Scroll Top Section
         * 
         * General Settings > Scroll Top
         * 
         * @uses $wp_customize->add_section() https://developer.wordpress.org/reference/classes/wp_customize_manager/add_section/
         * @since 1.0.0
         */
        $wp_customize->add_section( new Ogma_Customize_Section (
            $wp_customize, 'ogma_section_scroll_top',
                array(
                    'priority'  => 45,
                    'panel'     => 'ogma_panel_general',
                    'title'     => __( 'Scroll Top', 'ogma' ),
                )
            )
        );

        /**
         * Toggle option for scroll top.
         *
         * General Settings > Scroll Top
         *
         * @since 1.0.0
         */
        $wp_customize->add_setting( 'scroll_top_enable',
            array(
                'default'           => ogma_get_customizer_default( 'scroll_top_enable' ),
                'sanitize_callback' => 'ogma_sanitize_checkbox'
            )
        );
        $wp_customize->add_control( new Ogma_Control_Toggle(
            $wp_customize, 'scroll_top_enable',
                array(
                    'priority'      => 10,
                    'section'       => 'ogma_section_scroll_top',
                    'settings'      => 'scroll_top_enable',
                    'label'         => __( 'Enable Scroll Top', 'ogma' )
                )
            )
        );

        /**
         * Radio icons field for scroll top arrow
         *
         * General Settings > Scroll Top
         *
         * @since 1.0.0
         */
        $wp_customize->add_setting( 'scroll_top_arrow',
            array(
                'default'           => ogma_get_customizer_default( 'scroll_top_arrow' ),
                'sanitize_callback' => 'sanitize_text_field',
            )
        );
        $wp_customize->add_control( new Ogma_Control_Radio_Icons(
            $wp_customize, 'scroll_top_arrow',
                array(
                    'priority'          => 20,
                    'section'           => 'ogma_section_scroll_top',
                    'settings'          => 'scroll_top_arrow',
                    'label'             => __( 'Arrow Icon', 'ogma' ),
                    'description'       => __( 'Choose required arrow from available lists.', 'ogma' ),
                    'choices'           => ogma_scroll_top_arrow_choices(),
                    'active_callback'   => 'ogma_cb_has_enable_scroll_top'
                )
            )
        );

        /**
         * Upgrade field for scroll top
         * 
         * General Settings > Scroll Top
         *
         * @since 1.0.0
         */ 
        $wp_customize->add_setting( 'upgrade_scroll_top',
            array(
                'sanitize_callback' => 'sanitize_text_field'
            )
        );
        $wp_customize->add_control( new Ogma_Control_Upgrade(
            $wp_customize, 'upgrade_scroll_top',
                array(
                    'priority'      => 70,
                    'section'       => 'ogma_section_scroll_top',
                    'settings'      => 'upgrade_scroll_top',
                    'label'         => __( 'More Features with Ogma Pro', 'ogma' ),
                    'choices'       => ogma_upgrade_choices( 'ogma_scroll_top' )
                )
            )
        );

    }

endif;