<?php
/**
 * Displays Author bio in single post
 *
 * @package Ogma
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

$single_posts_author_enable = ogma_get_customizer_option_value( 'single_posts_author_enable' );

if ( ! is_single() || false === $single_posts_author_enable ) {
    return;
}

/**
 * hook - ogma_before_author_box
 * 
 * @since 1.0.0
 */
do_action( 'ogma_before_author_box' );

$author_id         = get_the_author_meta( 'ID' );
$author_avatar     = get_avatar( $author_id, 'thumbnail' );
$author_post_link  = get_the_author_posts_link();
$author_bio        = get_the_author_meta( 'description' );
$author_url        = get_the_author_meta( 'user_url' );

?>

<div class="post-author-box-wrapper">

        <?php if ( $author_avatar ) { ?>
            <div class="ogma-author__avatar">
                <?php echo wp_kses_post( $author_avatar ); ?>
            </div><!-- .ogma-author-avatar -->
        <?php } ?>

        <div class="ogma-author-info">
            <?php if ( $author_post_link ) { ?>
                    <h5 class="ogma-author-name"><?php echo wp_kses_post( $author_post_link ); ?></h5>
            <?php } ?>

            <?php if ( $author_bio ) { ?>
                <div class="ogma-author-bio">
                    <?php echo wp_kses_post( $author_bio ); ?>
                </div><!-- .ogma-author-bio -->
            <?php } ?>

            <div class="ogma-author-meta">
                <?php if ( $author_url ) { ?>
                    <div class="ogma-author-website">
                        <span><?php esc_html_e( 'Website', 'ogma' ); ?></span>
                        <a href="<?php echo esc_url( $author_url ); ?>" target="_blank"><?php echo esc_url( $author_url ); ?></a>
                    </div><!-- .ogma-author-website -->
                <?php } ?>
            </div><!-- .ogma-author-meta -->
        </div><!-- .ogma-author-info -->
</div><!-- .post-author-box-wrapper -->

<?php
/**
 * hook - ogma_after_author_box
 * 
 * @since 1.0.0
 */
do_action( 'ogma_after_author_box' );